.. ppmd-cffi documentation main index file, created by
   sphinx-quickstart on Mon Sep 28 14:52:30 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ppmd-cffi's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   user_guide
   contribution
   authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
